Changes

Struct Changes 

pub struct Changes { /* private fields */ }
Structure that represents the changes in a git repository

Implementations

Source

impl Changes

pub fn from_repo( repository: &impl RepositoryExtension, ) -> Result<Self, Box<dyn Error>>

Sort the commits from a given repo into major, minor, patch and other change categories according to their commit intentions.

Commits are fetched since the latest version tag. If there are no version tags yet then all the commits from the repository are fetched.

Returns

The Changes structure with the sorted commits or error type.

Example
use git2::Repository;
use cargo_semantic_release::Changes;

let git_repo = Repository::open(".").unwrap();

let changes = Changes::from_repo(&git_repo).expect("error during fetching changes");
println!("changes: {changes}")
pub fn define_action_for_semantic_version(self) -> SemanticVersionAction

Evaluate the changes find in a repository to figure out the semantic version action

Returns

SemanticVersionAction enum for the suggested semantic version change.

Example
 use git2::Repository;
 use cargo_semantic_release::Changes;

 let git_repo = Repository::open(".").unwrap();

 let action = Changes::from_repo(&git_repo).expect("Error during fetching changes").define_action_for_semantic_version();
 println!("suggested change of semantic version: {}", action);